==> haskell-quickcheck-io-0.2.0-846-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-4s6kxcBqmMr5jTF0dpyltD
key:                  quickcheck-io-0.2.0-4s6kxcBqmMr5jTF0dpyltD
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  efdaab3c63e8f2b98a8354435b0c92ce
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-4s6kxcBqmMr5jTF0dpyltD
depends:
    HUnit-1.6.2.0-8fflnSUyMts5yDZwSC6PCJ
    QuickCheck-2.14.3-EZ7TdgRzq7jKBweVl9M0jh base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-848-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-JgbWtPu6tLj5yKrYDxuV7x
key:                  quickcheck-io-0.2.0-JgbWtPu6tLj5yKrYDxuV7x
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  e950cf3732f51cab395753e349359121
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-JgbWtPu6tLj5yKrYDxuV7x
depends:
    HUnit-1.6.2.0-JlkHGrwnzdW73OrIAc87UZ
    QuickCheck-2.14.3-7hqZHxjEzJA3sWW6zgGwOZ base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
